﻿# Example #1 Backup Database

Backup-SqlDatabase -ServerInstance "LocalHost" -Database "1GBDB" -BackupFile "C:\Backups\1GBDBFull.bak"  

Backup-SqlDatabase -ServerInstance "LocalHost" -Database "1GBDB" -BackupFile "C:\Backups\1GBDBIncremental.bak" -Incremental

Backup-SqlDatabase -ServerInstance "LocalHost" -Database "1GBDB"  -BackupAction Log



$dbBackup = Get-SqlDatabase -ServerInstance "LocalHost" -Name "1GBDB" 

$dbBackup.LastBackupDate

$dbBackup.LastLogBackupDate



#Backs up all the datsbases

Get-ChildItem "SQLSERVER:\SQL\DESKTOP-JAL1J7S\Default\Databases" | Backup-SqlDatabase

Get-SqlDatabase -Credential $Credential -ServerInstance "LocalHost" | foreach{ Backup-SqlDatabase -DatabaseObject $_ -BackupFile $($_.NAME)_db_$(Get-Date -UFormat %Y%m%d%H%M).bak}



# List Files in the Folder

Get-ChildItem -Path C:\Backups

# Delete Files
 
Remove-Item C:\Backups\*.bak 

Remove-Item C:\Backups\*.trn

#Clean up your mess

Remove-Item "C:\Program Files\Microsoft SQL Server\MSSQL14.MSSQLSERVER\MSSQL\Backup\*.bak"


#==============================================================================

#No DEMO For this

#Parameters
$Path = "C:\PSDelete\" # Path where the backups are located
$Target = "C:\PSDelete\Exclude\" # Path where the backups are located
$Days = "2" # How old to keep
 
#DaysOld
$CutoffDate = (Get-Date).AddDays(-$Days)
 
#Get All bak Backups older than 2 days
Get-ChildItem -Path $Path*.bak -Recurse -File | Where-Object { $_.LastWriteTime -lt $CutoffDate } | move-item -destination $Target

#Get All trn Backups older than 2 days

Get-ChildItem -Path $Path*.trn -Recurse -File | Where-Object { $_.LastWriteTime -lt $CutoffDate } | move-item -destination $Target



#This code will delete any bak or trn files that are older than two days...including the exclude folder


#Parameters
$Path = "C:\PSDelete\" # Path where the backups are located
$Days = "2" # How old to keep
 
#DaysOld
$CutoffDate = (Get-Date).AddDays(-$Days)
 
#Get All bak Backups older than 2 days
Get-ChildItem -Path $Path*.bak -Recurse -File | Where-Object { $_.LastWriteTime -lt $CutoffDate } | Remove-Item –Force -Verbose

#Get All trn Backups older than 2 days

Get-ChildItem -Path $Path*.trn -Recurse -File | Where-Object { $_.LastWriteTime -lt $CutoffDate } | Remove-Item –Force -Verbose




#==============================================================================

# Example #2 Get Database Information

# General Database Information

Get-SqlDatabase -ServerInstance "LocalHost"


Get-SqlDatabase -ServerInstance "LocalHost" -Name "AdventureWorks2014" 


# Database Size

Invoke-SQLCmd -Query “sp_databases” -Database master -ServerInstance Localhost | Out-GridView



# Take a Database Offline


$dbOffline = Get-SqlDatabase -ServerInstance "LocalHost" -Name "test" 

Write-Host $dbOffline.Status -ForegroundColor DarkMagenta -BackgroundColor White


$dbOffline.SetOffline()

#Function Call


#$dbOffline.SetOffline   #Will not work




# Set database online


$dbOffline = Get-SqlDatabase -ServerInstance "LocalHost" -Name "test" 

Write-Host $dbOffline.Status -ForegroundColor DarkMagenta -BackgroundColor White

#Function Call



$dbOffline.SetOnline()


#==================================================================================

# Example #3 Query Windows Counters

# Use Monitor job

#==================================================================================

# Example 4 Export to CSV

$results = Invoke-Sqlcmd -ServerInstance localhost -Database AdminMonitor -Query "Select * from config"

Foreach ($ConfigItem in $results) {Write-Host("ConfigItem: " + $ConfigItem.ConfigTitle + ", ConfigValue:$" + $ConfigItem.ConfigValue)}

$results | Select-Object ConfigTitle, ConfigValue | Export-Csv -Path "C:\Users\daveb\Desktop\Powershell For the DBA\MonitorConfig.csv" -NoTypeInformation


# Clean up mess

Remove-Item "C:\Users\daveb\Desktop\Powershell For the DBA\MonitorConfig.csv" 

#==================================================================================


# Example 5 Try Catch

TRY
    {
    $results = Invoke-Sqlcmd -ServerInstance localhost -Database AdminMonitor -Query "Select * from config"

    Foreach ($ConfigItem in $results) {Write-Host("ConfigItem: " + $ConfigItem.ConfigTitle + ", ConfigValue:$" + $ConfigItem.ConfigValue)}

    $results | Select-Object ConfigTitle, ConfigValue | Export-Csv -Path "C:\Users\daveb\Desktop\Powershell For the DBA\MonitorConfig.csv" -NoTypeInformation # No Error

    # $results | Select-Object ConfigTitle, ConfigValue | Export-Csv -Path "C:\Users\daveb\Desktop\Powershell For the DA\MonitorConfig.csv" -NoTypeInformation # Error
    }
# END TRY
CATCH
    {
    Write-Host "There is an Error"
    }
#END CATCH

# Clean up mess

Remove-Item "C:\Users\daveb\Desktop\Powershell For the DBA\MonitorConfig.csv" 

#================================================================================

# Example 6 Call a Stored proc


Invoke-SQLCmd -Query “GetProductColors” -Database AdventureWorks2014 -ServerInstance Localhost | Out-GridView


# proc with a parameter


$productid = 1

# 316 and 319

Invoke-Sqlcmd -ServerInstance localhost -Database AdventureWorks2014 -Query "[dbo].[GetProducts] @producid = $productid" | Out-GridView


# Another way to call a proc

$Server = "localhost"
$Database = "AdventureWorks2014"
$SqlConn = New-Object System.Data.SqlClient.SqlConnection("Server = $Server; Database = $Database; Integrated Security = True;")
$SqlConn.Open()
$cmd = $SqlConn.CreateCommand()
$cmd.CommandType = 'StoredProcedure'
$cmd.CommandText = 'dbo.GetProducts'
$p1 = $cmd.Parameters.Add('@ProducID',[int])
$p1.ParameterDirection.Input
$p1.Value = 749
$results = $cmd.ExecuteReader()
$dt = New-Object System.Data.DataTable
$dt.Load($results)
$SqlConn.Close()
$dt | Export-Csv -LiteralPath "C:\Users\daveb\Desktop\Powershell For the DBA\Products.csv" -NoTypeInformation

# Clean up mess

Remove-Item "C:\Users\daveb\Desktop\Powershell For the DBA\Products.csv" 

